// requirements

// requires CSL_GetRandomInteger from my function library it must be named CSL_GetRandomInteger
// and should preferably be called in init.sqs like this:  CSL_GetRandomInteger = compile preprocessFile "CSL_functions\CSL_GetRandomInteger.sqf"

// requires CSL_GetHorizontalDistance from my function library it must be named CSL_GetHorizontalDistance
// and should preferably be called in init.sqs like this:  CSL_GetHorizontalDistance = compile preprocessFile "CSL_functions\CSL_GetHorizontalDistance.sqf"

// requires CSL_GetMoveIncrementInfantry from my function library it must be named CSL_GetMoveIncrementInfantry
// and should preferably be called in init.sqs like this:  CSL_GetMoveIncrementInfantry = compile preprocessFile "CSL_functions\CSL_GetMoveIncrementInfantry.sqf"

// requires CSL_Bring_Out_Your_Dead.sqf from my utility scripts.  Must be named like this: "CSL_Utility\CSL_Bring_Out_Your_Dead.sqf"

// requires CSL_RemoveGroupWhenDeadSimple.sqf from my utility scripts.  Must be named like this: "CSL_Utility\CSL_RemoveGroupWhenDeadSimple.sqf"

// CSL_PopulateIsland.sqf must be executed after a delay if it's executed in init.sqs.  It may not be called from an initline.

// there must be at least one civillian preplaced on the map somewhere.  It doesn't need anything special, like a name, or anything.  Just has to be placed

// call this script like this:
// [Position_Population_Area_Center,  Integer_Population_Area_Width, Integer_Population_Area_Height, Integer_Population_Count]  execVM "CSL_PopulateIsland\CSL_PopulateIsland.sqf"
// example:
// [getPos CSL_CivArea1Part1,  100, 100, 10]  execVM "CSL_PopulateIsland\CSL_PopulateIsland.sqf"
// preliminary testing shows that this formula works well for a reccomended population density, although you'll want to try higher/lower too, depending on the mission requirements.
// (height X width) / 1000
// (250 * 300) / 1000 = 75 civs.
// By all means though, try higher.  Double that may well work fine too, depending on how many other units are on the map
// and processor speed.




// this is a flag that should only be set for debugging purposes.
// it should only be used when you're trying it with a few groups only
// when used, it disables dynamic reduction altogether
CSL_PopulateIsland_Debugging_Override = false;


// declare private variables
private
[
    "_populationCenter",
    "_areaWidth",
    "_areaHeight",
    "_numberOfCivs",
    "_unitCount",
    "_unitTypes",
    "_unitPositions",
    "_civillianTypes",
    "_numberOfTypes",
    "_spawnCounter",
    "_unitString",
    "_spawnLocationXOffset",
    "_spawnLocationYOffset",
    "_spawnLocation"
];


//parameters

// population center They will spawn and wander around this area
// must be in position format.  Example: [123.45, 123.45, 0]
_populationCenter = _this select 0;

// the desired width of the population area
_areaWidth = _this select 1;

// the desired height of the population area
_areaHeight = _this select 2;

// max allowed 710.  it's highly reccomended you don't go this high in one area though,
// as most machines will be able to handle it that many AIs as of 2007
_numberOfCivs = _this select 3;




// preferences

// Civillian TypeArray.
// if you change this (not reccomended), be sure to change the _numberOfTypes below
// it's not reccomended you play with this if you don't understand what's going on here
_civillianTypes =
[
    "Civilian",
    "Civilian2",
    "Civilian3",
    "Civilian4",
    "Civilian5",
    "Civilian6",
    "Civilian7",
    "Civilian8",
    "Civilian9",
    "Civilian10",
    "Civilian11",
    "Civilian12",
    "Civilian13",
    "Civilian14",
    "Civilian15",
    "Civilian16",
    "Civilian17",
    "Civilian18",
    "Civilian19",
    "Civilian20",
    "Civilian21"
];

// should be the number of types above - 1 (because it's ordinal)
// so for 1 type only, use 0, for 10 types, use 9
// it's not reccomended you play with this if you don't understand what's going on here
_numberOfTypes = 20;



//*************************************************************
// IT IS STRONGLY RECCOMENDED YOU DO NOT EDIT BEYOND THIS POINT
// IT IS STRONGLY RECCOMENDED YOU DO NOT EDIT BEYOND THIS POINT
// IT IS STRONGLY RECCOMENDED YOU DO NOT EDIT BEYOND THIS POINT
// IT IS STRONGLY RECCOMENDED YOU DO NOT EDIT BEYOND THIS POINT
// IT IS STRONGLY RECCOMENDED YOU DO NOT EDIT BEYOND THIS POINT
//*************************************************************


// this is the unit count to pass to script B.  Script B is called for every group created
// and thus, the unit count will be different depening on the group and number of _numberOfCivs
_unitCount = 0;
// array of types to create, passed to script B in order to let it know what specific types of CIVS
// it's dealing with.
_unitTypes = [];
// array of the units starting positions, passed to script B in order to let it know where they all are
_unitPositions = [];

// counter used to know how many units have been created
_spawnCounter = 0;

// this loop feeds the group info to script B (the group reduction/spawn control script) until there
// is no more to feed or it hits a safety limit of 710 men
while {(_spawnCounter < _numberOfCivs) and (_spawnCounter < 710)} do
{
    // pick the CIV type
    _unitString = format["%1", _civillianTypes select ([0, _numberOfTypes] call CSL_GetRandomInteger)];

    // pick the starting location for this man
    _spawnLocationXOffset = [(_areaWidth  * -1), _areaWidth ] call CSL_GetRandomInteger;
    _spawnLocationYOffset = [(_areaHeight * -1), _areaHeight] call CSL_GetRandomInteger;
    _spawnLocation = [(_populationCenter select 0) + _spawnLocationXOffset, (_populationCenter select 1) + _spawnLocationyOffset, 0];

    // increment the counter
    _spawnCounter = _spawnCounter + 1;

    // setup the information to pass to the the next part of the script
    _unitCount     = _unitCount     + 1;
    _unitTypes     = _unitTypes     + [_unitString];
    _unitPositions = _unitPositions + [_spawnLocation];

    // start a group every 5th man and the last man, to decrease the number of groups used
    // without jepordising performance
    if (((_spawnCounter mod 5) == 0) or (_spawnCounter == _numberOfCivs)) then
    {
        // calls script B (the group reduction/spawn control script)
        [_populationCenter, _areaWidth, _areaHeight, _unitCount, _unitTypes, _unitPositions] execVM "CSL_PopulateIsland\CSL_PopulateIsland_B.sqf";

        // just a small delay to make sure the next script has time to grab those
        // arrays without them being reset
        sleep 0.1;

        // reset the variables holding the info to pass to script B (the group reduction/spawn control script)
        _unitCount = 0;
        _unitTypes = [];
        _unitPositions = [];
    };
};